@@ -2,7 +2,7 @@ import json
 
 import torch
 
-from tfkit.utility import tok
+from tfkit.utility import tok, batch_reduce_pad
 import numpy as np
 from math import log
 from itertools import combinations
@@ -36,26 +36,27 @@ class Predictor:
         self.model = model
 
     def gen_predict(self, input='', topK=1, topP=0.85, mode=['greedy', 'topK', 'topP'], decodenum=1,
-                    filtersim=True, reserved_len=0, task=None, handle_exceed='noop', eos_num=1):
+                    filtersim=False, reserved_len=0, task=None, handle_exceed='noop', eos_num=1, decode_maxlen=0,
+                    no_repeat=False):
         filtersim = json.loads(str(filtersim).lower())
         topK = int(topK)
         eos_num = int(eos_num)
         topP = float(topP)
         decodenum = int(decodenum)
+        decode_maxlen = int(decode_maxlen)
         mode = mode[0] if isinstance(mode, list) else mode.lower()
         previous = []
         if tok.UNIVERSAL_SEP in input:
             previous = self.model.tokenizer.tokenize(input.split(tok.UNIVERSAL_SEP)[-1])
             eos_num += 1
-
+        sep_tok = tok.tok_sep(self.model.tokenizer)
         sequences = [[[], 1.0]]
         with torch.no_grad():
             while True:
                 all_candidates = list()
                 exceed = False
                 for seq in sequences:
-                    if tok.tok_sep(self.model.tokenizer) not in seq[0] or seq[0].count(
-                            tok.tok_sep(self.model.tokenizer)) < eos_num:
+                    if sep_tok not in seq[0] or seq[0].count(sep_tok) < eos_num:
                         tokens, score = seq
                         if not tokens:
                             tokens = previous
@@ -69,13 +70,17 @@ class Predictor:
                             all_candidates.append(seq)
                             continue
 
+                        feature_dict = batch_reduce_pad([feature_dict])[0]
                         for k, v in feature_dict.items():
                             feature_dict[k] = [v]
-                        predictions = self.model.forward(feature_dict, eval=True, use_prev=True,beamsearch=decodenum>1)
-                        token_prob_list = predictions['label_prob_all'][0]
+                        predictions = self.model.forward(feature_dict, eval=True, use_prev=True,
+                                                         beamsearch=decodenum > 1,
+                                                         return_topN_prob=max(decodenum, topK))
+                        label_prob = predictions['label_prob'] if 'label_prob' in predictions else \
+                            [predictions['max_item']]
                         # topK topP
                         if 'top' in mode:
-                            prob_list = [prob for _, prob in token_prob_list]
+                            prob_list = predictions['prob_list']
                             if 'topk' in mode:
                                 sample_list = prob_list[:topK]
                                 decode_range = max(decodenum, topK)
@@ -93,14 +98,14 @@ class Predictor:
                                                                size=decodenum)
                             for idx in range(decodenum):
                                 sampling_index = prob_list.index(choice_list[idx])
-                                k, v = token_prob_list[sampling_index]
+                                k, v = label_prob[sampling_index]
                                 candidate = [tokens + [k], score + -log(v)]
                                 all_candidates.append(candidate)
 
                         # greedy / beam search
                         else:
-                            for k, v in token_prob_list[:50]:
-                                if len(tokens) > 0 and tokens[-1] == k or len(k) < 1:
+                            for k, v in label_prob[:50]:
+                                if (no_repeat and len(tokens) > 0 and tokens[-1] == k) or len(k) < 1:
                                     continue
                                 candidate = [tokens + [k], score + -log(v) if v > 0 else 0]
                                 all_candidates.append(candidate)
@@ -108,21 +113,22 @@ class Predictor:
                         all_candidates.append(seq)
 
                 ordered = sorted(all_candidates, key=lambda tup: tup[1])
-                if filtersim:
+                # ordered = all_candidates
+                if filtersim:  # default disable, it will took a lots of time on long sequence generation
                     _filter_similar(ordered, decodenum)
                 sequences = ordered[:decodenum]
                 stop = 0
                 for i in sequences:
                     # i[0] - sequence,i[1] - sequence score
-                    if (tok.tok_sep(self.model.tokenizer) in i[0] and i[0].count(
-                            tok.tok_sep(self.model.tokenizer)) >= eos_num) or \
-                            i[1] > self.model.maxlen:
+                    if (i[0].count(sep_tok) >= eos_num) or \
+                            len(i[0]) > self.model.maxlen or \
+                            0 < decode_maxlen < len(i[0]):
                         stop += 1
                 if stop == len(sequences) or exceed:
                     break
 
             for i in range(len(sequences)):
-                if tok.tok_sep(self.model.tokenizer) in sequences[i][0]:  # remove sep token
+                if sep_tok in sequences[i][0]:  # remove sep token
                     sequences[i][0] = sequences[i][0][:-1]
                 slide_len = len(previous) if len(previous) > 0 else 0
                 sequences[i][0] = self.model.tokenizer.decode(
